@@ -1,4 +1,4 @@
-// Copyright 2024 The Khronos Group
+// Copyright 2024-2025 The Khronos Group
 // SPDX-License-Identifier: Apache-2.0
 
 #include "Object.h"
@@ -11,7 +11,12 @@ Object::Object(ANARIDataType type, HeCoreDeviceGlobalState *s)
     : helium::BaseObject(type, s)
 {}
 
-void Object::commit()
+void Object::commitParameters()
+{
+  // no-op
+}
+
+void Object::finalize()
 {
   // no-op
 }
