@@ -1,21 +1,23 @@
-// Copyright 2024 The Khronos Group
+// Copyright 2024-2025 The Khronos Group
 // SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
+#include "geometry.h"
+// anari
+#include <anari/anari_cpp.hpp>
+// pxr
 #include <pxr/base/tf/token.h>
+#include <pxr/base/vt/types.h>
 #include <pxr/base/vt/value.h>
 #include <pxr/imaging/hd/enums.h>
-#include <anari/anari_cpp.hpp>
-
-// pxr
+#include <pxr/imaging/hd/geomSubset.h>
 #include <pxr/imaging/hd/sceneDelegate.h>
 #include <pxr/imaging/hd/types.h>
+#include <pxr/imaging/hf/perfLog.h>
 #include <pxr/pxr.h>
 #include <pxr/usd/sdf/path.h>
 
-#include "geometry.h"
-
 PXR_NAMESPACE_OPEN_SCOPE
 
 class HdAnariPoints final : public HdAnariGeometry
@@ -29,18 +31,31 @@ class HdAnariPoints final : public HdAnariGeometry
   HdDirtyBits GetInitialDirtyBitsMask() const override;
 
  protected:
-  HdAnariMaterial::PrimvarBinding UpdateGeometry(HdSceneDelegate *sceneDelegate,
+  HdGeomSubsets GetGeomSubsets(
+      HdSceneDelegate *sceneDelegate, HdDirtyBits *dirtyBits) override
+  {
+    return {};
+  }
+
+  HdAnariGeometry::GeomSpecificPrimvars GetGeomSpecificPrimvars(
+      HdSceneDelegate *sceneDelegate,
       HdDirtyBits *dirtyBits,
       const TfToken::Set &allPrimvars,
-      const VtValue &points) override;
-  void UpdatePrimvarSource(HdSceneDelegate *sceneDelegate,
+      const VtVec3fArray &points,
+      const SdfPath &geomsetId) override;
+  HdAnariGeometry::PrimvarSource UpdatePrimvarSource(
+      HdSceneDelegate *sceneDelegate,
       HdInterpolation interpolation,
       const TfToken &attributeName,
       const VtValue &value) override;
 
+  void Finalize(HdRenderParam *renderParam) override;
+
  private:
   HdAnariPoints(const HdAnariPoints &) = delete;
   HdAnariPoints &operator=(const HdAnariPoints &) = delete;
+
+  anari::Array1D m_radiiArray{};
 };
 
 PXR_NAMESPACE_CLOSE_SCOPE
\ No newline at end of file
